@@ -2,7 +2,7 @@ package Test2::Formatter;
 use strict;
 use warnings;
 
-our $VERSION = '1.302155'; # TRIAL
+our $VERSION = '1.302157'; # TRIAL
 
 
 my %ADDED;
@@ -19,6 +19,8 @@ sub new_root {
     return $class->new(@_);
 }
 
+sub supports_tables { 0 }
+
 sub hide_buffered { 1 }
 
 sub terminate { }
@@ -61,6 +63,8 @@ A formatter is any package or object with a C<write($event, $num)> method.
 
     sub finalize { }
 
+    sub supports_tables { return $BOOL }
+
     sub new_root {
         my $class = shift;
         ...
@@ -92,6 +96,15 @@ The C<finalize> method is always the last thing called on the formatter, I<<
 except when C<terminate> is called for a Bail event >>. It is passed the
 following arguments:
 
+The C<supports_tables> method should be true if the formatter supports directly
+rendering table data from the C<info> facets. This is a newer feature and many
+older formatters may not support it. When not supported the formatter falls
+back to rendering C<detail> instead of the C<table> data.
+
+The C<new_root> method is used when constructing a root formatter. The default
+is to just delegate to the regular C<new()> method, most formatters can ignore
+this.
+
 =over 4
 
 =item * The number of tests that were planned
